@@ -352,3 +352,71 @@ fn search_attr_exe(res: &mut Vec<String>, dom: &Dom, attr: &str) {
         }
     }
 }
+
+/// Returns the value of specific attributes for all tags.
+///
+/// # Examples
+/// Get the values of the `id` and` class` attributes of all tags.
+///
+/// ```rust
+/// use parsercher;
+///
+/// let html = r#"
+/// <!DOCTYPE html>
+/// <html>
+///   <head>
+///     <meta charset="UTF-8">
+///     <meta id="id1">
+///     <title>sample html</title>
+///   </head>
+///   <body id="id2" class="class1">
+///     <h1>sample</h1>
+///
+///     <div align="center" class="class2"></div>
+///
+///     <ol>
+///       <li>first</li>
+///       <li class="class3">second</li>
+///       <li>therd</li>
+///     </ol>
+///   </body>
+/// </html>
+/// "#;
+///
+/// let dom = parsercher::parse(&html).unwrap();
+///
+/// let attrs = vec!("id", "class");
+/// let values = parsercher::search_attrs(&dom, &attrs).unwrap();
+/// assert_eq!(values.len(), 5);
+/// assert_eq!(values[0], "id1".to_string());
+/// assert_eq!(values[1], "id2".to_string());
+/// assert_eq!(values[2], "class1".to_string());
+/// assert_eq!(values[3], "class2".to_string());
+/// assert_eq!(values[4], "class3".to_string());
+/// ```
+pub fn search_attrs<'a>(dom: &Dom, attrs: &Vec<&str>) -> Option<Vec<String>> {
+    let mut res: Vec<String> = Vec::new();
+    search_attrs_exe(&mut res, dom, attrs);
+    if res.is_empty() {
+        return None;
+    }
+    Some(res)
+}
+
+fn search_attrs_exe(res: &mut Vec<String>, dom: &Dom, attrs: &Vec<&str>) {
+    if DomType::Tag == dom.dom_type {
+        if let Some(tag) = dom.get_tag() {
+            for attr in attrs.iter() {
+                if let Some(value) = tag.get_attr(attr) {
+                    res.push(value);
+                }
+            }
+        }
+    }
+
+    if let Some(children) = dom.get_children() {
+        for child in children.iter() {
+            search_attrs_exe(res, child, attrs);
+        }
+    }
+}
